@@ -5,6 +5,7 @@
 #include <QFile>
 #include <phonon/MediaObject>
 #include <phonon/MediaSource>
+#include <reader.h>
 /*extern "C"
 {
     #include "flite.h"
@@ -24,11 +25,13 @@ signals:
 
 public slots:
     void audioFinished();
+    void threadFinished();
 
 private:
     QString file;
     QFile *audioFile;
     Phonon::MediaObject *music;
+    Reader *reader;
 
 
 signals:
